@@ -1,5 +1,5 @@
 import re
-from collections import defaultdict
+from collections import OrderedDict
 from itertools import zip_longest
 from string import Template
 from typing import List, Optional, Union
@@ -18,28 +18,36 @@ from commitizen.git import GitCommit
 
 
 def find_increment(
-    commits: List[GitCommit], regex: str = bump_pattern, increments_map: dict = bump_map
+    commits: List[GitCommit],
+    regex: str = bump_pattern,
+    increments_map: Union[dict, OrderedDict] = bump_map,
 ) -> Optional[str]:
 
+    if isinstance(increments_map, dict):
+        increments_map = OrderedDict(increments_map)
+
     # Most important cases are major and minor.
     # Everything else will be considered patch.
-    increments_map_default = defaultdict(lambda: None, increments_map)
-    pattern = re.compile(regex)
+    select_pattern = re.compile(regex)
     increment = None
 
     for commit in commits:
         for message in commit.message.split("\n"):
-            result = pattern.search(message)
-            if not result:
-                continue
-            found_keyword = result.group(0)
-            new_increment = increments_map_default[found_keyword]
-            if increment == "MAJOR":
-                continue
-            elif increment == "MINOR" and new_increment == "MAJOR":
-                increment = new_increment
-            elif increment == "PATCH" or increment is None:
-                increment = new_increment
+            result = select_pattern.search(message)
+            if result:
+                found_keyword = result.group(0)
+                new_increment = None
+                for match_pattern in increments_map.keys():
+                    if re.match(match_pattern, found_keyword):
+                        new_increment = increments_map[match_pattern]
+                        break
+
+                if increment == "MAJOR":
+                    continue
+                elif increment == "MINOR" and new_increment == "MAJOR":
+                    increment = new_increment
+                elif increment == "PATCH" or increment is None:
+                    increment = new_increment
 
     return increment
 
@@ -58,10 +66,12 @@ def prerelease_generator(current_version: str, prerelease: Optional[str] = None)
         return ""
 
     version = Version(current_version)
-    new_prerelease_number: int = 0
-    if version.is_prerelease and prerelease.startswith(version.pre[0]):
-        prev_prerelease: int = list(version.pre)[1]
+    # version.pre is needed for mypy check
+    if version.is_prerelease and version.pre and prerelease.startswith(version.pre[0]):
+        prev_prerelease: int = version.pre[1]
         new_prerelease_number = prev_prerelease + 1
+    else:
+        new_prerelease_number = 0
     pre_version = f"{prerelease}{new_prerelease_number}"
     return pre_version
 
@@ -168,7 +178,8 @@ def create_tag(version: Union[Version, str], tag_format: Optional[str] = None):
 
     major, minor, patch = version.release
     prerelease = ""
-    if version.is_prerelease:
+    # version.pre is needed for mypy check
+    if version.is_prerelease and version.pre:
         prerelease = f"{version.pre[0]}{version.pre[1]}"
 
     t = Template(tag_format)
